==> rc-ui-lib-0.3.0.tgz: package/es/image-preview/ImagePreviewItem.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import React, { useContext } from 'react';
import classnames from 'classnames';
import { useGesture } from '@use-gesture/react';
import { useSpring, animated } from '@react-spring/web';
import Image from '../image';
import ConfigProviderContext from '../config-provider/ConfigProviderContext';

var ImagePreviewItem = function ImagePreviewItem(props) {
  var _useContext = useContext(ConfigProviderContext),
      prefixCls = _useContext.prefixCls,
      createNamespace = _useContext.createNamespace;

  var _createNamespace = createNamespace('image-preview', prefixCls),
      _createNamespace2 = _slicedToArray(_createNamespace, 1),
      bem = _createNamespace2[0];

  var _useSpring = useSpring(function () {
    return {
      zoom: 1,
      x: 0,
      y: 0,
      config: {
        tension: 300
      }
    };
  }),
      _useSpring2 = _slicedToArray(_useSpring, 2),
      _useSpring2$ = _useSpring2[0],
      zoom = _useSpring2$.zoom,
      x = _useSpring2$.x,
      y = _useSpring2$.y,
      api = _useSpring2[1];

  var bind = useGesture({
    onDrag: function onDrag(state) {
      if (state.tap && state.elapsedTime > 0) {
        // 判断点击时间>0是为了过滤掉非正常操作，例如用户长按选择图片之后的取消操作（也是一次点击）
        props.onTap();
        return;
      }

      var _state$swipe = _slicedToArray(state.swipe, 2),
          swipeX = _state$swipe[0],
          swipeY = _state$swipe[1];

      var currentZoom = zoom.get();

      if (currentZoom <= 1 || swipeX !== 0 || swipeY !== 0) {
        api.start({
          x: 0,
          y: 0,
          immediate: true
        });
      } else {
        var _state$offset = _slicedToArray(state.offset, 2),
            offsetX = _state$offset[0],
            offsetY = _state$offset[1];

        api.start({
          x: offsetX,
          y: offsetY,
          immediate: true
        });
      }
    },
    onPinch: function onPinch(state) {
      var _props$onZoomChange;

      var _state$offset2 = _slicedToArray(state.offset, 1),
          d = _state$offset2[0];

      var currentZoom = state.last ? Math.max(Math.min(d, props.maxZoom), 1) : d;
      api.start({
        zoom: currentZoom,
        immediate: !state.last
      });
      (_props$onZoomChange = props.onZoomChange) === null || _props$onZoomChange === void 0 ? void 0 : _props$onZoomChange.call(props, currentZoom);

      if (state.last && currentZoom <= 1) {
        api.start({
          x: 0,
          y: 0,
          immediate: true
        });
      }
    }
  }, {
    drag: {
      from: function from() {
        return [x.get(), y.get()];
      }
    },
    pinch: {
      distanceBounds: {
        min: 1,
        max: props.maxZoom
      },
      rubberband: true,
      from: function from() {
        return [zoom.get(), 0];
      }
    }
  });
  return /*#__PURE__*/React.createElement("div", {
    className: classnames(bem('slide')),
    onPointerMove: function onPointerMove(e) {
      if (zoom.get() !== 1) {
        e.stopPropagation();
      }
    }
  }, /*#__PURE__*/React.createElement("div", _extends({
    className: classnames(bem('control'))
  }, bind()), /*#__PURE__*/React.createElement(animated.div, {
    className: classnames(bem('image-wrapper')),
    style: {
      scale: zoom,
      x: x,
      y: y
    }
  }, /*#__PURE__*/React.createElement(Image, {
    fit: "contain",
    src: props.image,
    className: classnames(bem('image')) // lazyload={props.lazyload}
    ,
    onClick: function onClick() {
      var _props$onTap;

      (_props$onTap = props.onTap) === null || _props$onTap === void 0 ? void 0 : _props$onTap.call(props);
    }
  }))));
};

export default ImagePreviewItem;

==> rc-ui-lib-1.3.4.tgz: package/es/image-preview/ImagePreviewItem.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import React, { useContext } from 'react';
import classnames from 'classnames';
import { useGesture } from '@use-gesture/react';
import { useSpring, animated } from '@react-spring/web';
import Image from '../image';
import ConfigProviderContext from '../config-provider/ConfigProviderContext';

var ImagePreviewItem = function ImagePreviewItem(props) {
  var _useContext = useContext(ConfigProviderContext),
      prefixCls = _useContext.prefixCls,
      createNamespace = _useContext.createNamespace;

  var _createNamespace = createNamespace('image-preview', prefixCls),
      _createNamespace2 = _slicedToArray(_createNamespace, 1),
      bem = _createNamespace2[0];

  var _useSpring = useSpring(function () {
    return {
      zoom: 1,
      x: 0,
      y: 0,
      config: {
        tension: 300
      }
    };
  }),
      _useSpring2 = _slicedToArray(_useSpring, 2),
      _useSpring2$ = _useSpring2[0],
      zoom = _useSpring2$.zoom,
      x = _useSpring2$.x,
      y = _useSpring2$.y,
      api = _useSpring2[1];

  var bind = useGesture({
    onDrag: function onDrag(state) {
      if (state.tap && state.elapsedTime > 0) {
        // 判断点击时间>0是为了过滤掉非正常操作，例如用户长按选择图片之后的取消操作（也是一次点击）
        props.onTap();
        return;
      }

      var _state$swipe = _slicedToArray(state.swipe, 2),
          swipeX = _state$swipe[0],
          swipeY = _state$swipe[1];

      var currentZoom = zoom.get();

      if (currentZoom <= 1 || swipeX !== 0 || swipeY !== 0) {
        api.start({
          x: 0,
          y: 0,
          immediate: true
        });
      } else {
        var _state$offset = _slicedToArray(state.offset, 2),
            offsetX = _state$offset[0],
            offsetY = _state$offset[1];

        api.start({
          x: offsetX,
          y: offsetY,
          immediate: true
        });
      }
    },
    onPinch: function onPinch(state) {
      var _props$onZoomChange;

      var _state$offset2 = _slicedToArray(state.offset, 1),
          offsetX = _state$offset2[0];

      var currentZoom = state.last ? Math.max(Math.min(offsetX, props.maxZoom), 1) : offsetX;
      api.start({
        zoom: currentZoom,
        immediate: !state.last
      });
      (_props$onZoomChange = props.onZoomChange) === null || _props$onZoomChange === void 0 ? void 0 : _props$onZoomChange.call(props, currentZoom);

      if (state.last && currentZoom <= 1) {
        api.start({
          x: 0,
          y: 0,
          immediate: true
        });
      }
    }
  }, {
    drag: {
      from: function from() {
        return [x.get(), y.get()];
      }
    },
    pinch: {
      distanceBounds: {
        min: 1,
        max: props.maxZoom
      },
      rubberband: true,
      from: function from() {
        return [zoom.get(), 0];
      }
    }
  });
  return /*#__PURE__*/React.createElement("div", {
    className: classnames(bem('slide')),
    "data-testid": "slide",
    onPointerMove: function onPointerMove(e) {
      if (zoom.get() !== 1) {
        e.stopPropagation();
      }
    }
  }, /*#__PURE__*/React.createElement("div", _extends({
    className: classnames(bem('control'))
  }, bind(), {
    "data-testid": "control"
  }), /*#__PURE__*/React.createElement(animated.div, {
    className: classnames(bem('image-wrapper')),
    style: {
      scale: zoom,
      x: x,
      y: y
    }
  }, /*#__PURE__*/React.createElement(Image, {
    fit: "contain",
    src: props.image,
    className: classnames(bem('image')),
    onClick: function onClick() {
      var _props$onTap;

      (_props$onTap = props.onTap) === null || _props$onTap === void 0 ? void 0 : _props$onTap.call(props);
    }
  }))));
};

export default ImagePreviewItem;
